@@ -3,7 +3,7 @@ from .decidir_sdk.DecidirSDK import DecidirSDK
 
 
 class SDK:
-    def __init__(self, merchant: dict, processor: str = None):
+    def __init__(self, merchant: dict, processor: str = None, merchant_cadena: dict = None):
         # Si se le indica el procesador
         self.processor = processor
         if processor == 'mercadopago' and merchant['credentials']['mercadopago']['active']:
@@ -13,15 +13,7 @@ class SDK:
             self._sdk = MercadoPagoSDK(merchant, marketplace=True)
             return
         elif processor == 'decidir' and merchant['credentials']['decidir']['active']:
-            self._sdk = DecidirSDK(merchant)
-            return
-        # # Si no utiliza el preferrred_processor que tenga el merchant
-        # if 'credentials' in merchant and merchant['credentials']['preferred_processor'] == 'decidir':
-        #     self._sdk = DecidirSDK(merchant)
-        #     self.processor = 'decidir'
-        # else:
-        #     self._sdk = MercadoPagoSDK(merchant)
-        #     self.processor = 'mercadopago'
+            self._sdk = DecidirSDK(merchant, merchant_cadena)
 
     def customer(self):
         return self._sdk.customer()
