@@ -6,8 +6,8 @@ from .Refund import Refund
 
 
 class DecidirSDK:
-    def __init__(self, merchant, merchant_cadena=None,site_id=None):
-        if merchant_cadena:
+    def __init__(self, merchant, merchant_cadena=None,site_id=None,distributed=False):
+        if distributed:
             credentials = merchant_cadena['credentials']['decidir']
             self.payment_type = 'distributed'
         else:
