@@ -84,7 +84,7 @@ class Payment:
             application_fee = round(payment_data['application_fee'], 2) * 100
             body['sub_payments'] = [
                 {
-                    'site_id': self.seller_site_id,
+                    'site_id': payment_data['seller_site_id'],
                     'installments': 1,
                     'amount': total_amount - application_fee
                 }, {
