@@ -42,10 +42,19 @@ class Payment:
             "installments": 1,
         }
 
-        if 'additional_info' in payment_data:
-            payment_data_mp["additional_info"] = payment_data['additional_info']
-        if 'description' in payment_data:
-            payment_data_mp["description"] = payment_data['description']
+        optional_fields = [
+            'additional_info',
+            'description',
+            'external_reference',
+            'point_of_interaction',
+            'installments',
+            'payment_method_id',
+            'application_fee'
+        ]
+        for f in optional_fields:
+            if f in payment_data:
+                payment_data_mp[f] = payment_data[f]
+
         if 'payer' in payment_data:
             payment_data_mp["payer"] = {
                 "first_name": payment_data['payer']["nombre"],
@@ -56,14 +65,6 @@ class Payment:
                 payment_data_mp['payer']['id'] = payment_data['payer']["mercadopago_id"]
             elif 'email' in payment_data['payer']:
                 payment_data_mp['payer']['email'] = payment_data['payer']["email"]
-        if 'external_reference' in payment_data:
-            payment_data_mp["external_reference"] = payment_data['external_reference']
-        if 'point_of_interaction' in payment_data:
-            payment_data_mp["point_of_interaction"] = payment_data['point_of_interaction']
-        if 'installments' in payment_data:
-            payment_data_mp["installments"] = payment_data['installments']
-        if 'payment_method_id' in payment_data:
-            payment_data_mp["payment_method_id"] = payment_data['payment_method_id']
 
         payment_response = self.sdk.payment().create(payment_data_mp)
         if payment_response['status'] < 400:
